@@ -9,12 +9,9 @@ mod web_context;
 pub use web_context::WebContextImpl;
 
 #[cfg(target_os = "macos")]
+use cocoa::appkit::{NSView, NSViewHeightSizable, NSViewWidthSizable};
 use cocoa::{
-  appkit::{NSView, NSViewHeightSizable, NSViewWidthSizable},
-  base::YES,
-};
-use cocoa::{
-  base::id,
+  base::{id, nil, NO, YES},
   foundation::{NSDictionary, NSFastEnumeration, NSInteger},
 };
 
@@ -29,7 +26,7 @@ use std::{
 use core_graphics::geometry::{CGPoint, CGRect, CGSize};
 use objc::{
   declare::ClassDecl,
-  runtime::{Class, Object, Sel},
+  runtime::{Class, Object, Sel, BOOL},
 };
 use objc_id::Id;
 
@@ -55,10 +52,10 @@ use crate::http::{
 };
 
 pub struct InnerWebView {
-  webview: id,
+  pub(crate) webview: id,
   #[cfg(target_os = "macos")]
-  ns_window: id,
-  manager: id,
+  pub(crate) ns_window: id,
+  pub(crate) manager: id,
   // Note that if following functions signatures are changed in the future,
   // all fucntions pointer declarations in objc callbacks below all need to get updated.
   ipc_handler_ptr: *mut (Box<dyn Fn(&Window, String)>, Rc<Window>),
@@ -186,7 +183,7 @@ impl InnerWebView {
             // Send data
             let bytes = content.as_ptr() as *mut c_void;
             let data: id = msg_send![class!(NSData), alloc];
-            let data: id = msg_send![data, initWithBytes:bytes length:content.len()];
+            let data: id = msg_send![data, initWithBytesNoCopy:bytes length:content.len() freeWhenDone: if content.len() == 0 { NO } else { YES }];
             let () = msg_send![task, didReceiveData: data];
           } else {
             let urlresponse: id = msg_send![class!(NSHTTPURLResponse), alloc];
@@ -359,6 +356,47 @@ impl InnerWebView {
         null_mut()
       };
 
+      // File upload panel handler
+      extern "C" fn run_file_upload_panel(
+        _this: &Object,
+        _: Sel,
+        _webview: id,
+        open_panel_params: id,
+        _frame: id,
+        handler: id,
+      ) {
+        unsafe {
+          let handler = handler as *mut block::Block<(id,), c_void>;
+          let cls = class!(NSOpenPanel);
+          let open_panel: id = msg_send![cls, openPanel];
+          let _: () = msg_send![open_panel, setCanChooseFiles: YES];
+          let allow_multi: BOOL = msg_send![open_panel_params, allowsMultipleSelection];
+          let _: () = msg_send![open_panel, setAllowsMultipleSelection: allow_multi];
+          let allow_dir: BOOL = msg_send![open_panel_params, allowsDirectories];
+          let _: () = msg_send![open_panel, setCanChooseDirectories: allow_dir];
+          let ok: NSInteger = msg_send![open_panel, runModal];
+          if ok == 1 {
+            let url: id = msg_send![open_panel, URLs];
+            (*handler).call((url,));
+          } else {
+            (*handler).call((nil,));
+          }
+        }
+      }
+
+      let ui_delegate = match ClassDecl::new("WebViewUIDelegate", class!(NSObject)) {
+        Some(mut ctl) => {
+          ctl.add_method(
+            sel!(webView:runOpenPanelWithParameters:initiatedByFrame:completionHandler:),
+            run_file_upload_panel as extern "C" fn(&Object, Sel, id, id, id, id),
+          );
+          ctl.register()
+        }
+        None => class!(WebViewUIDelegate),
+      };
+      let ui_delegate: id = msg_send![ui_delegate, new];
+      let _: () = msg_send![webview, setUIDelegate: ui_delegate];
+
       // File drop handling
       #[cfg(target_os = "macos")]
       let file_drop_ptr = match attributes.file_drop_handler {
@@ -372,7 +410,14 @@ impl InnerWebView {
 
       // ns window is required for the print operation
       #[cfg(target_os = "macos")]
-      let ns_window = window.ns_window() as id;
+      let ns_window = {
+        let ns_window = window.ns_window() as id;
+
+        // `1` means `none`, see https://developer.apple.com/documentation/appkit/nstitlebarseparatorstyle/none
+        let () = msg_send![ns_window, setTitlebarSeparatorStyle: 1];
+
+        ns_window
+      };
 
       let w = Self {
         webview,
@@ -505,11 +550,6 @@ r#"Object.defineProperty(window, 'ipc', {
 
   pub fn focus(&self) {}
 
-  /// Open the web inspector which is usually called dev tool.
-  ///
-  /// ## Platform-specific
-  ///
-  /// - **iOS:** Not implemented.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn open_devtools(&self) {
     #[cfg(target_os = "macos")]
@@ -520,11 +560,6 @@ r#"Object.defineProperty(window, 'ipc', {
     }
   }
 
-  /// Close the web inspector which is usually called dev tool.
-  ///
-  /// ## Platform-specific
-  ///
-  /// - **iOS:** Not supported.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn close_devtools(&self) {
     #[cfg(target_os = "macos")]
@@ -535,11 +570,6 @@ r#"Object.defineProperty(window, 'ipc', {
     }
   }
 
-  /// Gets the devtool window's current vibility state.
-  ///
-  /// ## Platform-specific
-  ///
-  /// - **iOS:** Not supported.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn is_devtools_open(&self) -> bool {
     #[cfg(target_os = "macos")]
@@ -560,6 +590,12 @@ r#"Object.defineProperty(window, 'ipc', {
       (view_frame.size.width as f64, view_frame.size.height as f64).into();
     logical.to_physical(scale_factor)
   }
+
+  pub fn zoom(&self, scale_factor: f64) {
+    unsafe {
+      let _: () = msg_send![self.webview, setPageZoom: scale_factor];
+    }
+  }
 }
 
 pub fn platform_webview_version() -> Result<String> {
@@ -597,6 +633,11 @@ impl Drop for InnerWebView {
         }
       }
 
+      // WKWebview has a single WKProcessPool to manage web contents.
+      // The WKProcessPool is not reset even if WKWebview is deallocated.
+      // So we need to override the process by navigating to `about:blank`.
+      self.navigate("about:blank");
+
       let _: Id<_> = Id::from_ptr(self.webview);
       #[cfg(target_os = "macos")]
       let _: Id<_> = Id::from_ptr(self.ns_window);
